# The traj module

This module contains some high-level utility functions that are directly written in Python and serve the purpose of streamlining the creation and use of trajectory objects.

```eval_rst
.. toctree::
   :maxdepth: 2

.. currentmodule:: baggianalysis.traj

.. autosummary::
    :nosignatures:

    LAMMPSTrajectory
    OxDNATrajectory
    
.. autofunction:: LAMMPSTrajectory
.. autofunction:: OxDNATrajectory
    
```